@@ -1,6 +1,7 @@
 /* 
  *   Creation Date: <2001/01/31 21:05:23 samuel>
- *   Time-stamp: <2004/02/22 13:58:49 samuel>
+ *   Time-stamp: <2004/02/22 14:19:39 samuel>
+ *
  *   
  *	<cpu.c>
  *	
@@ -25,13 +26,14 @@
 #include "rvec.h"
 #include "os_interface.h"
 #include "constants.h"
-#include "io.h"
+#include "drivers.h"
 #include "promif.h"
 #include "mol_assert.h"
 #include "breakpoints.h"
 #include "processor.h"
 #include "byteorder.h"
 #include "booter.h"
+#include "hostirq.h"
 
 /* exports to mainloop_asm.S */
 extern int	_rvec_spr_read( int dummy_rvec, int sprnum, int gprnum );
@@ -823,6 +825,19 @@ _rvec_io_write( int dummy_rvec, ulong mphys_ioaddr, void *usr_data )
 	return ret;
 }
 
+/************************************************************************/
+/*	check interrupts						*/
+/************************************************************************/
+
+static int
+rvec_check_irqs(int rvec)
+{
+	hostirq_check_irqs();
+
+	msr_modified();
+
+	return 0;
+}
 
 /************************************************************************/
 /*	debugger CMDs							*/
@@ -1067,6 +1082,9 @@ static rvec_entry_t rvecs[] = {
 	/* debugger */
 	{ RVEC_BREAK,		rvec_break, 		"Break"			},
 
+	/* check interrupts */
+	{ RVEC_CHECK_IRQS,	rvec_check_irqs,	"check interrupts" },
+
 #ifdef EMULATE_603
 	/* 603 vectors */
 	{ RVEC_DMISS_LOAD_TRAP,	rvec_dmiss_load_trap,	"Soft DMISS Load Trap"	},
