@@ -365,8 +365,11 @@ cmdline_setcursor( void )
 {
 	int	v,h;
 
+#if 0
+	/* This code seems useless, the address will always be true */
 	if( !cmdline_setcursor )
 		return;
+#endif
 
 	getmaxyx( stdscr, v,h );
 	move( v-1,1+pos );
