@@ -1,12 +1,12 @@
 /* 
  *   Creation Date: <97/06/18 13:58:23 samuel>
- *   Time-stamp: <2003/09/03 21:54:42 samuel>
+ *   Time-stamp: <2004/02/07 23:41:35 samuel>
  *   
  *	<monitor.c>
  *	
  *	The debugger interface
  *   
- *   Copyright (C) 1997, 1999, 2000, 2001, 2002, 2003 Samuel Rydh
+ *   Copyright (C) 1997, 1999, 2000, 2001, 2002, 2003, 2004 Samuel Rydh
  *   
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public License
@@ -155,9 +155,7 @@ monitor_init( void )
 	inp_win = stdscr;
 
 	scrollok( inst_win, TRUE );
-	/* the result will be better if scrollok is FALSE */
-	/* when the window is smaller than its contents */
-	scrollok( data_win, FALSE  ); 
+	scrollok( data_win, FALSE );
 
 	/* --- inst window ---- */
 	inst_top_ptr = (char*)0;
@@ -296,7 +294,7 @@ static void
 set_data_win_mode( int new_mode )
 {
 	data_win_mode = new_mode;
-	scrollok( data_win, FALSE );
+	scrollok( data_win, new_mode == mem_mode );
 	werase( data_win );
 	draw_data_win(0);
 	cmdline_setcursor();
@@ -815,7 +813,7 @@ draw_data_win( int scroll )
 {
 	switch( data_win_mode ) {
 	case mem_mode:
-		draw_mem_mode( scroll);
+		draw_mem_mode( scroll );
 		break;
 	case spr_mode:
 		draw_spr_mode();
@@ -1120,9 +1118,9 @@ draw_mem_mode( int scroll )
 	/* clear_cache(); */
 
 	/* MMU-context to use for displaying data */
-	context = ( dm_forced_context )? dm_forced_context : get_data_context();
+	context = dm_forced_context ? dm_forced_context : get_data_context();
 
-	getmaxyx( data_win, v,h );
+	getmaxyx( data_win, v, h );
 	start_y = 1;
 	end_y = v-2;
 	
@@ -1133,11 +1131,11 @@ draw_mem_mode( int scroll )
 			end_y = v-2;
 		} else {
 			start_y = 1;
-			end_y = (-scroll);
+			end_y = -scroll;
 		}
 	}
 
-	for(y=start_y; y<=end_y; y++ ) {
+	for( y=start_y; y <= end_y; y++ ) {
 		char str[9];
 
 		wmove( data_win, y, 0 );
@@ -1436,7 +1434,7 @@ cmd_il( int numargs, char **args )
 	il_forced_context = 0;
 	if( numargs== 3 ) {
 		il_forced_context = kContextMapped_S;
-		if( toupper(*args[2])=='U' )
+		if( toupper(*args[2]) == 'X' )
 			il_forced_context = kContextUnmapped;
 	}
 
@@ -1462,7 +1460,7 @@ cmd_dm( int numargs, char **args )
 	dm_forced_context = 0;
 	if( numargs== 3 ) {
 		dm_forced_context = kContextMapped_S;
-		if( toupper(*args[2])=='U' )
+		if( toupper(*args[2]) == 'X' )
 			dm_forced_context = kContextUnmapped;
 	}
 
@@ -1645,11 +1643,73 @@ cmd_bats( int numargs, char **args )
 	return 0;
 }
 
+
+
+/************************************************************************/
+/*	breakpoints							*/
+/************************************************************************/
+
+/* set breakpoint breakpoint */
+static int
+cmd_br( int numargs, char**args ) 
+{
+	ulong addr;
+	int flags;
+
+	if( numargs >= 4 )
+		return 1;
+
+	if( numargs == 1 )
+		addr = mregs->nip + 4;
+	else
+		addr = string_to_ulong(args[1]);
+
+	flags = ppc_mode ? 0 : br_m68k;
+	if( ppc_mode && numargs == 3 )
+		flags |= (toupper(args[2][0])=='X') ? br_phys_ea : br_transl_ea;
+
+	printm("Setting breakpoint at %08lX\n", addr );
+	dbg_add_breakpoint( addr, flags, 0 );
+
+	clear_cache();
+	refresh_debugger();
+	return 0;
+}
+
+/* set decrementer breakpoint */
+static int
+cmd_brd( int numargs, char**args ) 
+{
+	ulong addr;
+	int dec=0;
+	
+	if( numargs > 3 )
+		return 1;
+
+	if( numargs >= 2 )
+		addr = string_to_ulong(args[1]);
+	else
+		addr = mregs->nip+4;
+
+	if( numargs == 3 )
+		dec = string_to_ulong(args[2] );
+	if( dec <= 0 )
+		dec = 1;
+
+	printm("Adding decrementer breakpoint at 0x%08lX\n",addr);
+	dbg_add_breakpoint( addr, br_dec_flag, dec );
+
+	clear_cache();
+	refresh_debugger();
+	return 0;
+}
+
+
 void 
 install_monitor_cmds( void ) 
 {
-	add_cmd( "il", "il [addr] [U|M]\ndisassemble from addr\n", -1, cmd_il );
-	add_cmd( "dm", "dm addr [U|M]\ndisplay memory from addr\n", -1, cmd_dm );
+	add_cmd( "il", "il [addr] [X|M]\ndisassemble from addr\n", -1, cmd_il );
+	add_cmd( "dm", "dm addr [X|M]\ndisplay memory from addr\n", -1, cmd_dm );
 	add_cmd( "sx", "sx \nshow DEBUG registers\n", -1, cmd_sx );
 	add_cmd( "regs", "regs \nshow registers\n", -1, cmd_regs );
 	add_cmd( "fregs", "fregs \nshow FPU registers\n", -1, cmd_fregs );
@@ -1657,5 +1717,8 @@ install_monitor_cmds( void )
 	add_cmd( "sfd", "sfd [stack addr] \ndisplay stack chain (Darwin)\n", -1, cmd_sf );
 	add_cmd( "dil", "dil addr [len] \ndisassembly from addr\n", -1, cmd_dil );
 	add_cmd( "bats", "bats \ntoggle display between I/D BATS\n",-1,cmd_bats );
+
+	add_cmd( "br", "br [addr] [X|M]\nadd breakpoint\n", -1, cmd_br );
+	add_cmd( "brd", "brd [addr] [dec] \nadd decrementer breakpoint\n", -1, cmd_brd );
 }
 
