@@ -1,6 +1,6 @@
 /* 
  *   Creation Date: <97/07/19 17:20:37 samuel>
- *   Time-stamp: <2003/08/26 15:06:00 samuel>
+ *   Time-stamp: <2004/02/08 17:51:02 samuel>
  *   
  *	<mmu_cmds.c>
  *	
@@ -523,9 +523,7 @@ cmd_tlbie( int numargs, char **args )
 	return 0;
 }
 
-/* mmu consistency check. Things has changed since this function was written - 
- * it might or might not do a good job.
- */
+/* mmu consistency check */
 static int __dbg
 cmd_mmucc( int numargs, char **args ) 
 {
@@ -559,9 +557,9 @@ cmd_mmucc( int numargs, char **args )
 			continue;
 
 		if( pte.rpn != (page.phys>>12) ) {
-			printm("Inconsistency: EA: %08lx LVPTR: %p LINUX_PHYS: "
-			       "%08x PTE_PHYS: %08x\n",
-			       mac_ea, lvptr, pte.rpn << 12, page.phys );
+			printm("Inconsistency: EA: %08lx -> LVPTR: %p -> PHYS: %x (flags %x) "
+			       "PTE-PHYS: %08x\n",
+			       mac_ea, lvptr, page.phys, page.mflags, pte.rpn << 12 );
 		}
 	}
 	return 0;
@@ -619,7 +617,7 @@ do_search( const char *key, char *lvbase, int mbase, int size )
 			j = (lvbase[i] == key[j])? j+1 : 0;
 		else {
 			int phys = mbase + i - j;
-			unsigned char *p = lvbase + i - j;
+			unsigned char *p = (unsigned char *)(lvbase + i - j);
 			while( *p >= 32 && *p < 127 )
 				p--;
 			j=0;
