@@ -1,6 +1,6 @@
 /* 
  *   Creation Date: <1999-01-16 19:45:15 samuel>
- *   Time-stamp: <2003/06/10 12:26:25 samuel>
+ *   Time-stamp: <2004/02/07 18:34:15 samuel>
  *   
  *	<dbdma.c>
  *	
@@ -31,6 +31,7 @@
 #include "gc.h"
 #include "dbdma_hw.h"
 #include "byteorder.h"
+#include "drivers.h"
 
 SET_VERBOSE_NAME("dbdma");
 
@@ -233,7 +234,14 @@ dump_dbdma_cmd( ulong mphys )
 {
 	struct dbdma_cmd *cp = (struct dbdma_cmd*)transl_ro_mphys( mphys );
 	short cmd;
-	
+
+	union {
+		unsigned int * p;	/* Physical data address */
+		ulong * l;
+	} addr_convert;
+
+	ulong * phy_addr;
+
 	if( !cp ) {
 		printm("dbdma: bad access\n");
 		return;
@@ -246,9 +254,15 @@ dump_dbdma_cmd( ulong mphys )
 	       key_names[(cmd>>8)&0x7] );
 	printm("I:%02X  BR:%02X  W:%02X\n", (cmd & 0x30)>>4, 
 	       (cmd&0xc)>>2, (cmd&0x3) );
+
+
+	addr_convert.p = &cp->phy_addr;
+	phy_addr = addr_convert.l;
+	addr_convert.p = &cp->cmd_dep;
+	
 	printm("req_count: %04X   phy_addr: %08X   cmd_dep: %08X\n", 
-	       ld_le16( &cp->req_count ), ld_le32( (ulong*)&cp->phy_addr), 
-	       ld_le32( (ulong*)&cp->cmd_dep ) );
+	       ld_le16( &cp->req_count ), ld_le32( phy_addr ), 
+	       ld_le32( addr_convert.l ) );
 	printm("res_count: %04X   xfer_status: %04X\n",
 	       ld_le16( &cp->res_count ), ld_le16( &cp->xfer_status ));
 }
@@ -436,11 +450,17 @@ prepare_cmd( struct dbdma_channel *ch )
 {
 	ulong 	cp_phys;
 	int 	s;
+
+	union {
+		struct dbdma_cmd * d;
+		char * c;
+	} cur_cmd;
 	
 	cp_phys = ld_le32( &ch->reg[r_cmdptr]);
 	
 	/* check that the address is valid (in RAM/ROM) */
-	s = mphys_to_lvptr( cp_phys, (char**)&ch->cur_cmd );
+	cur_cmd.d = ch->cur_cmd;
+	s = mphys_to_lvptr( cp_phys, (char **) cur_cmd.c );
 	
 	ch->cur_cmd_in_rom = 0;
 	if( s<0 ) {
@@ -496,6 +516,11 @@ start_cmd( struct dbdma_channel *ch )
 	int	key;
 	ulong	addr;
 	int	req_count;
+	
+	union {
+		unsigned int * p;	/* Physical data address */
+		ulong * l;
+	} addr_convert;
 
 #ifdef DEBUG_DMA
 	printm("\n");
@@ -521,7 +546,8 @@ start_cmd( struct dbdma_channel *ch )
 		ch->may_branch = 1;
 
 		req_count = ld_le16( &cp->req_count );
-		addr = ld_le32( (ulong*)&cp->phy_addr );
+		addr_convert.p = &(cp->phy_addr);
+		addr = ld_le32( addr_convert.l );
 		
 		if( key == 0x400 ) {
 			printm("DBDMA: Reserved KEY 0x400\n");
@@ -546,7 +572,8 @@ start_cmd( struct dbdma_channel *ch )
 				VPRINT("DBDMA [%d]: Illegal key type %d\n", ch->irq, key );
 			key = KEY_SYSTEM;
 		}
-		addr = ld_le32( (ulong*)&cp->phy_addr );
+		addr_convert.p = &(cp->phy_addr);
+		addr = ld_le32( addr_convert.l );
 		req_count = ld_le16( &cp->req_count ) & 0x7;
 
 		/* endian stuff */
@@ -1007,6 +1034,8 @@ dma_wait( int irq, int flags, struct timespec *abstimeout )
 	pthread_cond_t *cond = NULL;
 	int retval = DMA_ERROR;
 
+	ret.ret = 0;
+
 	LOCK( ch );
 	if( (flags & DMA_RW) == DMA_RW ) {
 		if( !(ch->cmd_phase == outputing || ch->cmd_phase == inputing) || ch->status & PAUSE ) {
