@@ -1,12 +1,12 @@
 /* 
  *   Creation Date: <2001/05/09 23:26:42 samuel>
- *   Time-stamp: <2003/07/29 21:54:27 samuel>
+ *   Time-stamp: <2004/03/24 01:24:35 samuel>
  *   
  *	<disk.h>
  *	
  *	Block-device related
  *   
- *   Copyright (C) 2001, 2002, 2003 Samuel Rydh (samuel@ibrium.se)
+ *   Copyright (C) 2001, 2002, 2003, 2004 Samuel Rydh (samuel@ibrium.se)
  *   
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public License
@@ -56,7 +56,8 @@ typedef struct bdev_desc {
 
 extern void 		bdev_setup_drives( void );
 
-extern bdev_desc_t	*bdev_get_volume( void );
+extern bdev_desc_t	*bdev_get_next_volume( bdev_desc_t *last );
+extern void		bdev_claim_volume( bdev_desc_t *bdev );
 extern void		bdev_close_volume( bdev_desc_t *dev );
 
 extern int		reserve_scsidev( int host, int channel, int unit_id );
