@@ -1,12 +1,12 @@
 /* 
  *   Creation Date: <1999/06/14 22:51:59 samuel>
- *   Time-stamp: <1999/07/05 23:41:20 samuel>
+ *   Time-stamp: <2004/02/07 18:13:40 samuel>
  *   
  *	<hacks.c>
  *	
  *	Various hacks
  *   
- *   Copyright (C) 1999 Samuel Rydh (samuel@ibrium.se)
+ *   Copyright (C) 1999, 2004 Samuel Rydh (samuel@ibrium.se)
  *   
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public License
@@ -18,22 +18,17 @@
 #include "hacks.h"
 #include "debugger.h"
 #include "promif.h"
-
-/**** BEGIN DRIVER INTERFACE ****/
-
 #include "driver_mgr.h"
 
-driver_interface_t      hacks_driver =
-{
-    "hacks", hacks_init, NULL
-};
-
-/***** END DRIVER INTERFACE *****/
-
-
 static int hacks = 0;
 
-int
+int 
+get_hacks( void )
+{
+	return hacks;
+}
+
+static int
 hacks_init( void )
 {
 	hacks = 0;
@@ -41,15 +36,9 @@ hacks_init( void )
 		printm("Starmax hack activated\n");
 		hacks |= hack_starmax;
 	}
-	
 	return 1;
 }
 
-int 
-get_hacks()
-{
-	return hacks;
-}
-
-
-
+driver_interface_t hacks_driver = {
+    "hacks", hacks_init, NULL
+};
