@@ -1,12 +1,12 @@
 /* 
  *   Creation Date: <1999-02-04 06:04:39 samuel>
- *   Time-stamp: <2002/11/16 15:10:03 samuel>
+ *   Time-stamp: <2004/06/12 21:31:35 samuel>
  *   
  *	<scsi-bus.c>
  *	
  *	SCSI bus emulation
  *   
- *   Copyright (C) 1999 Samuel Rydh (samuel@ibrium.se)
+ *   Copyright (C) 1999, 2004 Samuel Rydh (samuel@ibrium.se)
  *   
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public License
@@ -204,7 +204,7 @@ static void start_status_transfer( void );
 
 static int get_mes_len( int len, char *buf );
 
-static int default_mes_handler( int mes_len, char *buf, void *dummy_usr );
+static int default_mes_handler( int mes_len, unsigned char *buf, void *dummy_usr );
 static int default_next_sphase( int sphase, void *usr );
 
 static int go_next_phase( void );
@@ -727,14 +727,14 @@ do_mes_handling( int may_block )
 	PREREQ( sphase_mes_out );
 
 	CALL_USER;
-	what = bus->target->pb.handle_mes_proc( xf->req_count, xf->buf, bus->target->usr_data );
+	what = bus->target->pb.handle_mes_proc( xf->req_count, (unsigned char *) xf->buf, bus->target->usr_data );
 	IF_ABORTED return 0;
 	CALL_USER_END;
 
 	if( what == SCSI_DEF_MES_HANDLER ){
 		/* currently the CALL_USER guard is unnecessary here */
 		CALL_USER;
-		what = default_mes_handler( xf->req_count, xf->buf, NULL );
+		what = default_mes_handler( xf->req_count, (unsigned char *)xf->buf, NULL );
 		IF_ABORTED return 0;
 		CALL_USER_END;
 
@@ -858,7 +858,7 @@ do_cmd_handling( int may_block )
 	int		ret;
 
 	CALL_USER;
-	ret = bus->target->pb.handle_cmd_proc( xf->req_count, xf->buf, may_block, bus->target->usr_data );
+	ret = bus->target->pb.handle_cmd_proc( xf->req_count, (unsigned char *) xf->buf, may_block, bus->target->usr_data );
 	IF_ABORTED return 0;
 	CALL_USER_END;
 
@@ -1088,7 +1088,7 @@ default_next_sphase( int sphase, void *dummy_usr )
  * the MESSAGE_OUT phase.
  */
 static int
-default_mes_handler( int mes_len, char *buf, void *dummy_usr )
+default_mes_handler( int mes_len, unsigned char *buf, void *dummy_usr )
 {
 	int ret = 0;
 #ifdef DEBUG_SCSI
