@@ -594,7 +594,7 @@ cuda_incoming( void )
 	
 	switch( cuda.in_buffer[0] ) {
 	case ADB_PACKET:
-		adb_packet( cuda.in_buffer[1], cuda.in_buffer+2,
+		adb_packet( cuda.in_buffer[1], (unsigned char *) (cuda.in_buffer+2),
 			   cuda.in_count-2 );
 		break;
 	case CUDA_PACKET:
