@@ -1,6 +1,6 @@
 /* 
  *   Creation Date: <1999/03/13 23:09:47 samuel>
- *   Time-stamp: <2004/01/12 20:46:50 samuel>
+ *   Time-stamp: <2004/02/07 18:15:15 samuel>
  *   
  *	<video.c>
  *	
@@ -42,6 +42,7 @@
 #include "session.h"
 #include "input.h"
 #include "video_sh.h"
+#include "hacks.h"
 
 
 #define DEFAULT_VBL_HZ		85
@@ -103,7 +104,9 @@ typedef struct video_state {
 static video_state_t 		vc[1];
 
 static struct { int w, h; } std_res[] = {
-	{ 640, 480 }, { 800, 600 }, { 1024, 768 }, { 1152, 864 }, { 1280, 1024 }, { 1600, 1200 }
+	{ 640, 480 }, { 800, 600 }, { 1024, 768 }, { 1152, 864 },
+	{ 1280, 1024 }, { 1440, 960 }, { 1600, 1024 }, { 1600, 1200 },
+	{ 1680, 1050 }
 };
 
 static video_module_t *video_mods[] = {
@@ -682,7 +685,7 @@ get_vmode_str( video_desc_t *vm, char *buf, int size )
 	return buf;
 }
 
-int
+static int
 get_video_info( ulong *mphys, int *w, int *h, int *rb, int *depth)
 {
 	video_desc_t *vm = &vc->cur_vmode;
