@@ -622,7 +622,7 @@ vnc_thread( void *arg )
 
 	LOG("vnc_thread starts as pid %d\n", getpid());
  
-	snprintf( buffer, 256, rfbProtocolVersionFormat, rfbProtocolMajorVersion,
+	snprintf( (char *)buffer, 256, rfbProtocolVersionFormat, rfbProtocolMajorVersion,
 		  rfbProtocolMinorVersion);
 
 	if( !write_exact(buffer, 12) )
@@ -652,7 +652,7 @@ vnc_thread( void *arg )
 	if( !write_exact((unsigned char *)&server_init, sizeof(server_init)) )
 		goto endo;
  
-	if( !write_exact(display_name, strlen(display_name)) )
+	if( !write_exact((unsigned char *)display_name, strlen(display_name)) )
 		goto endo;
 
 	force_redraw = true;
@@ -1282,7 +1282,7 @@ vnc_rcv_connection( int fd, int event )
 		return;
 	}
 
-	if( (new_socket=accept(fd, (struct sockaddr*)&addr, &len)) < 0 ) {
+	if( (new_socket=accept(fd, (struct sockaddr*)&addr, (unsigned int *) &len)) < 0 ) {
 		perrorm("vnc_accept");
 		return;
 	}
@@ -1414,7 +1414,7 @@ vopen( video_desc_t *org_vm )
 
 	pthread_mutex_lock(&buffers_mutex);
  
-	offscreen_buf = map_zero( NULL, FBBUF_SIZE(org_vm));
+	offscreen_buf = (unsigned char *) map_zero( NULL, FBBUF_SIZE(org_vm));
 
 	//output_buf_size = org_vm->w * 4;
 	output_buf_size = 10000;
@@ -1424,7 +1424,7 @@ vopen( video_desc_t *org_vm )
 	// Fill in the fields video.c expects
 	org_vm->mmu_flags = MAPPING_FB_ACCEL | MAPPING_FORCE_CACHE;
 	org_vm->map_base = 0;
-	org_vm->lvbase = offscreen_buf;
+	org_vm->lvbase = (char *)offscreen_buf;
 
 	vmode = *org_vm;
 
