@@ -72,7 +72,7 @@ check_if_png( char *fname, FILE **retf )
 	if( !((f=fopen(fname, "ro"))) )
 		return 0;
 	ret = fread(buf, 1, PNG_BYTES_TO_CHECK, f) == PNG_BYTES_TO_CHECK;
-	ret = ret && !png_sig_cmp(buf, (png_size_t)0, PNG_BYTES_TO_CHECK);
+	ret = ret && !png_sig_cmp((png_bytep) buf, (png_size_t)0, PNG_BYTES_TO_CHECK);
 	
 	*retf = f;
 	if( !ret )
@@ -147,7 +147,7 @@ create_x_picture( int *retw, int *reth )
 	w.im->byte_order = MSBFirst;
 
 	for( i=0; i<height ; i++ ) {
-		convert_from_24( rows[i], buf + i*rb, width, x11.xdepth, x11.byte_order == MSBFirst );
+		convert_from_24( (char *) rows[i], buf + i*rb, width, x11.xdepth, x11.byte_order == MSBFirst );
 	}
 	ret = 0;
 	*retw = width, *reth = height;
