@@ -1,6 +1,6 @@
 /* 
  *   Creation Date: <1999/12/21 20:40:23 samuel>
- *   Time-stamp: <2004/03/05 12:02:22 samuel>
+ *   Time-stamp: <2004/06/12 18:27:23 samuel>
  *   
  *	<xvideo.c>
  *	
@@ -177,23 +177,29 @@ endian_conv_15( int x, int y, int w, int h )
 	}
 }
 
+#ifdef __ppc__
 static inline void
-conv_15_to_le16( ushort *p, ulong x )
+conv_15_to_le16( u16 *p, u32 x )
 {
 	asm ("rlwimi %0,%0,1,16,25" : "+r" (x) : );
 	asm ("rlwinm %0,%1,0,27,25" : "=r" (x) : "r" (x) );
 	asm ("sthbrx %1,0,%2" : "=m" (*p) : "r" (x), "r" (p) );
 }
 
-static inline ulong
-conv_le16_to_15( ushort *p )
+static inline u32
+conv_le16_to_15( u16 *p )
 {
-	ulong r;
+	u32 r;
 	asm ("lhbrx %0,0,%1" : "=r" (r) : "r" (p), "m" (*p) );
 	asm ("rlwimi %0,%0,31,17,26" : "+r" (r) : );
 	asm ("rlwinm %0,%1,0,17,31" : "=r" (r) : "r" (r) );
 	return r;
 }
+#else
+/* fixme */
+static inline void conv_15_to_le16( u16 *p, u32 x ) { *p = x; }
+static inline u32 conv_le16_to_15( u16 *p ) { return *p; }
+#endif
 
 static void
 endian_conv_16( int x, int y, int w, int h ) 
@@ -230,7 +236,7 @@ endian_conv_16b( int x, int y, int w, int h )
 
 	pp = start;
 	for( ; h-- > 0 ; pp += vmode.rowbytes ) {
-		ushort *p = (ushort*)pp;
+		u16 *p = (u16*)pp;
 		if( w & 1 ) {
 			p[0] = conv_le16_to_15( p );
 			p++;
@@ -249,6 +255,7 @@ endian_conv_16b( int x, int y, int w, int h )
 	}
 }
 
+#ifdef __ppc__
 static inline ulong
 conv_15_to_16( ulong x )
 {
@@ -264,6 +271,11 @@ conv_16_to_15( ulong x )
 	asm ("rlwinm %0,%1,0,17,31" : "=r" (x) : "r" (x) );
 	return x;
 }
+#else
+/* fixme */
+static inline u32 conv_15_to_16( u32 x ) { return x; }
+static inline u32 conv_16_to_15( u32 x ) { return x; }
+#endif
 
 static void
 convert_555_to_565( int x, int y, int w, int h ) 
@@ -497,6 +509,7 @@ blit_rect( int x, int y, int w, int h )
 	else
 		XPutImage( x11.disp, vs.win, vs.the_gc, vs.img, x, y, x, y, w, h );
 
+	XSync( x11.disp, 0);
 	if( vs.blit_hook_post )
 		vs.blit_hook_post( x, y, w, h );
 }
@@ -827,9 +840,9 @@ vopen( video_desc_t *org_vm )
 	org_vm->mmu_flags = MAPPING_FB_ACCEL | MAPPING_FORCE_CACHE;
 	org_vm->map_base = 0;
 	if( !vs.depth_emulation ) {
-		vmode.lvbase = org_vm->lvbase = vs.the_buffer;
+		vmode.lvbase = org_vm->lvbase = (char *)vs.the_buffer;
 	} else {
-		vmode.lvbase = vs.the_buffer;
+		vmode.lvbase = (char *)vs.the_buffer;
 		org_vm->lvbase = vs.offscreen_buf;
 	}
 	mac_vmode = *org_vm;
@@ -1020,7 +1033,7 @@ init_window( int width, int height )
 #endif
 
 	if( !vs.use_x_cursor ) {
-		vs.no_cursor_bitmap = XCreateBitmapFromData( x11.disp, vs.win, no_cursor_data, 8,8);
+		vs.no_cursor_bitmap = XCreateBitmapFromData( x11.disp, vs.win, (char *)no_cursor_data, 8,8);
 		if( vs.no_cursor_bitmap != None ){
 			vs.no_x_cursor = XCreatePixmapCursor( x11.disp, vs.no_cursor_bitmap, 
 							      vs.no_cursor_bitmap, &x11.black, &x11.black, 0, 0);
