@@ -1,6 +1,6 @@
 /* 
  *   Creation Date: <2001/08/15 01:11:01 samuel>
- *   Time-stamp: <2003/08/27 22:47:56 samuel>
+ *   Time-stamp: <2003/10/24 10:22:00 samuel>
  *   
  *	<kuname.c>
  *	
@@ -16,6 +16,11 @@
 
 #include <linux/config.h>
 #include <linux/version.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,18)
+#include <linux/utsrelease.h>
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)
 
 #ifdef CONFIG_SMP
 #define SMP_STRING	"-smp"
@@ -23,15 +28,14 @@
 #define SMP_STRING	""
 #endif
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)
-
 #ifndef CONFIG_ALTIVEC
 #define ALTIVEC_STRING	"-noav"
 #else
 #define ALTIVEC_STRING	""
 #endif
 
-#else 
+#else
+#define SMP_STRING	""
 #define ALTIVEC_STRING	""
 #endif
 
