@@ -1,6 +1,6 @@
 /* 
  *   Creation Date: <2002/07/13 13:58:00 samuel>
- *   Time-stamp: <2003/08/27 15:21:06 samuel>
+ *   Time-stamp: <2004/02/14 12:47:09 samuel>
  *   
  *	<mmu.c>
  *	
@@ -32,17 +32,10 @@ void		(*xx_store_pte_lowmem)( ulong *slot, int pte0, int pte1 );
 int
 arch_mmu_init( kernel_vars_t *kv )
 {
-	ulong sdr1 = _get_sdr1();
-	
-	if( !sdr1 ) { 
-		/* Linux does not use SDR1 for the 603[e]. We just create the hash table. */
-		if( create_pte_hash(kv, 1 /* set sdr1 */) )
-			return 1;
-	} else {
-		mPTE_t *base = (mPTE_t*)phys_to_virt( sdr1 & ~0xffff );
-		share_pte_hash( kv, sdr1, base );
-	}
-
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,18)
+	MMU.emulator_context = current->mm->context.id;
+#else
 	MMU.emulator_context = current->mm->context;
+#endif
 	return 0;
 }
