@@ -70,6 +70,12 @@ prom_get_root( void )
 	return oftree.root;
 }
 
+mol_device_node_t *
+prom_get_allnext( void )
+{
+	return oftree.allnext;
+}
+
 /* returns linked list with nodes */
 mol_device_node_t *
 prom_find_type( const char *type )
@@ -79,8 +85,8 @@ prom_find_type( const char *type )
 	
 	prevp = &head;
 	for( np=oftree.allnext; np ; np=np->allnext) {
-		char *p = prom_get_property( np, "device_type", &len);
-		if( strlen(type)+1 == len && !strcasecmp(type, p) ) {
+		unsigned char *p = prom_get_property( np, "device_type", &len);
+		if( strlen(type)+1 == len && !strcasecmp( (const  char *) type, (const char *) p) ) {
 			*prevp = np;
 			prevp = &np->next;
 		}
@@ -89,14 +95,18 @@ prom_find_type( const char *type )
 	return head;
 }
 
-static char *
+/* Returns the node name */
+static unsigned char *
 node_name( mol_device_node_t *dn ) 
 {
-	char *p;
+	unsigned char *p;
 	int len;
 
 	p = prom_get_property( dn, "name", &len );
-	return (!len || p[len-1])? "" : p;
+	if(!len || p[len-1])
+		return (unsigned char *) "";
+	else
+		return p;
 }
 
 mol_device_node_t *
@@ -117,7 +127,7 @@ prom_find_dev_by_path( const char *path )
 
 		dn2 = dn;
 		for( dn=dn->child ; dn ; dn=dn->sibling )
-			if( !strcasecmp(node_name(dn), s) )
+			if( !strcasecmp((char *) node_name(dn), (char *) s) )
 				break;
 		if( dn )
 			continue;
@@ -131,7 +141,7 @@ prom_find_dev_by_path( const char *path )
 			if( !dn->unit_string )
 				continue;
 			/* handle the /parent/node@2 case */
-			if( strlen(s2) && strcasecmp(node_name(dn),s2) )
+			if( strlen(s2) && strcasecmp( (char *)node_name(dn), (char *)s2) )
 				continue;
 			if( *dn->unit_string == '*' )
 				break;
@@ -150,7 +160,7 @@ prom_find_devices( const char *name )
 
 	prevp = &head;
 	for( np=oftree.allnext; np ; np=np->allnext ) {
-		if( !strcasecmp(node_name(np), name) ) {
+		if( !strcasecmp( (char *)node_name(np), (char *)name) ) {
 			*prevp = np;
 			prevp = &np->next;
 		}
@@ -206,7 +216,7 @@ prom_get_property( mol_device_node_t *dn, const char *name, int *lenp )
 	if( (pp=find_property( dn, name )) ) {
 		if( lenp )
 			*lenp = pp->length;
-		return pp->value ? (char*)pp->value : "";
+		return pp->value ? (unsigned char*)pp->value : (unsigned char *)"";
 	}
 	return NULL;
 }
@@ -216,7 +226,7 @@ prom_get_prop_by_path( const char *path, int *retlen )
 {
 	mol_device_node_t *dn;
 	char *p, *cpy = strdup(path);
-	char *ret=NULL;
+	unsigned char *ret=NULL;
 
 	if( retlen )
 		*retlen=0;
@@ -259,7 +269,7 @@ void
 prom_add_property( mol_device_node_t *dn, const char *name, const char *data, int len )
 {
 	p_property_t *pp;
-	char *ptr = NULL;
+	unsigned char *ptr = NULL;
 
 	if( (pp=find_property(dn, name)) ) {
 		if( pp->length >= len )
@@ -294,7 +304,7 @@ _get_full_name( mol_device_node_t *dn, char *buf, int len )
 
 	/* root node name (e.g. devic-tree) should not be included */
 	if( dn->parent )
-		strncat0( buf, node_name(dn), len );
+		strncat0( buf, (char *) node_name(dn), len );
 	if( dn->unit_string )
 		strncat3( buf, "@", dn->unit_string, len );
 }
@@ -637,7 +647,7 @@ export_node( mol_device_node_t *dn, FILE *file, int ind )
 
 	/* drop uninteresting nodes */
 	for( ns=&drop_nodes[0]; *ns; ns++ )
-		if( !strcmp(node_name(dn), *ns) ) {
+		if( !strcmp((char *) node_name(dn), *ns) ) {
 			export_node( dn->sibling, file, ind );
 			return;
 		}
@@ -690,7 +700,7 @@ export_node( mol_device_node_t *dn, FILE *file, int ind )
 		if( i==pr->length && !pr->value[i-1] ) {
 			fprintf(file, "<str>  \t");
 			ind += INDENT_VALUE;
-			for( i=0; i<pr->length; i += strlen(&pr->value[i]) + 1 ) {
+			for( i=0; i<pr->length; i += strlen((char *) &pr->value[i]) + 1 ) {
 				if( i )
 					fprintf(file, ", ");
 				if( pr->length > 50 ) {
@@ -935,6 +945,11 @@ build_node( char *buf )
 	mol_device_node_t *dn;
 	char *start, *end;
 
+	union {
+		void *	v;
+		int *	i;
+	} node_num;
+
 	dn = obstack_alloc( &oftree.stack, sizeof(mol_device_node_t) );
 	memset( dn, 0, sizeof(mol_device_node_t) );
 
@@ -947,7 +962,8 @@ build_node( char *buf )
 
 	/* phandle field -- used internally by MOL as node identifier */
 	if( findkey( buf, "mol_phandle", &start, NULL )) {
-		sscanf( start, "%x", (int*)&dn->node );
+		node_num.v = &dn->node;
+		sscanf( start, "%x", node_num.i);
 		if( (ulong)dn->node < PHANDLE_BASE ) {
 			printm("-----> molrc: mol_phandle field 0x%lX < 0x%x\n", 
 			       (ulong)dn->node, PHANDLE_BASE );
@@ -983,7 +999,7 @@ build_node( char *buf )
 				continue;
 			start = strchr( start, '>' ) + 1;
 			*end = 0;
-			pr->value = (*fe->proc)( start, &pr->length, fe->refcon );
+			pr->value = (unsigned char *)((*fe->proc)( start, &pr->length, fe->refcon ));
 			*end = ')';
 			break;
 		}
@@ -1137,8 +1153,9 @@ osip_prom_iface( int sel, int *args )
 {
 	int len, ph = args[1];
 	mol_device_node_t *dn;
-	char *p, *buf, *pdata;
+	char *p, *buf;
 	char tmpbuf[256];
+	unsigned char *pdata;
 	
 	if( args[0] == kPromClose ) {
 		if( !debugger_enabled() )
